bulkdata.pyNastran
==================

Since `pyNastran`_ is not a required package, if ``bulkdata`` is
unable to import it, this local ``pyNastran`` package is used as
a fallback. It contains copies of the `pyNastran`_ modules
containing the required functions.


.. _`pyNastran`: https://github.com/SteveDoyle2/pyNastran